==> rune.js-1.0.3.tgz: package/src/color.js <==
// This code was adapted from the brilliant color lib by MoOx
// See more here: https://github.com/MoOx/color
var colorConvert = require('color-convert');

var Color = function(a, b, c, d, e) {

  this.values = {
    rgb: [0, 0, 0],
    hsl: [0, 0, 0],
    hsv: [0, 0, 0],
    hwb: [0, 0, 0],
    cmyk: [0, 0, 0, 0],
    alpha: 1
  }

  // COLOR
  if(a instanceof Color) {
    return a;
  }

  // HSB
  else if(a == 'hsv') {
    this.setValues('hsv', {h:b % 360, s:c, v:d});
    if(e) this.setValues('alpha', e);
  }

  // HEX
  else if(typeof a === 'string') {

    // convert HEX to RGB
    var result = /^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i.exec(a);
    if(result) {
      this.setValues('rgb', [parseInt(result[1], 16), parseInt(result[2], 16), parseInt(result[3], 16)])
    } else {
      throw new Error("Unable to parse color from string \"" + a + "\"");
    }
    if(b) this.setValues('alpha', b);
  }

  // GRAYSCALE
  else if(typeof c === 'undefined') {
    this.setValues('rgb', {r:a, g:a, b:a});
    if(b) this.setValues('alpha', b);
  }

  // RGB
  else if(typeof a !== 'undefined') {
    this.setValues('rgb', {r:a, g:b, b:c});
    if(d) this.setValues('alpha', d);
  }

};

Color.prototype = {

  type: "color",

  rgb: function(vals) {
    return this.setSpace("rgb", arguments);
  },

  hsl: function(vals) {
    return this.setSpace("hsl", arguments);
  },

  hsv: function(vals) {
    return this.setSpace("hsv", arguments);
  },

  hwb: function(vals) {
    return this.setSpace("hwb", arguments);
  },

  cmyk: function(vals) {
    return this.setSpace("cmyk", arguments);
  },

  rgbArray: function() {
    return this.values.rgb;
  },

  hslArray: function() {
    return this.values.hsl;
  },

  hsvArray: function() {
    return this.values.hsv;
  },

  hwbArray: function() {
    if (this.values.alpha !== 1) {
      return this.values.hwb.concat([this.values.alpha])
    }
    return this.values.hwb;
  },

  cmykArray: function() {
    return this.values.cmyk;
  },

  rgbaArray: function() {
    var rgb = this.values.rgb;
    return rgb.concat([this.values.alpha]);
  },

  hslaArray: function() {
    var hsl = this.values.hsl;
    return hsl.concat([this.values.alpha]);
  },

  alpha: function(val) {
    if (val === undefined) {
       return this.values.alpha;
    }
    this.setValues("alpha", val);
    return this;
  },

  red: function(val) {
    return this.setChannel("rgb", 0, val);
  },

  green: function(val) {
    return this.setChannel("rgb", 1, val);
  },

  blue: function(val) {
    return this.setChannel("rgb", 2, val);
  },

  hue: function(val) {
    return this.setChannel("hsl", 0, val);
  },

  saturation: function(val) {
    return this.setChannel("hsl", 1, val);
  },

  lightness: function(val) {
    return this.setChannel("hsl", 2, val);
  },

  saturationv: function(val) {
    return this.setChannel("hsv", 1, val);
  },

  whiteness: function(val) {
    return this.setChannel("hwb", 1, val);
  },

  blackness: function(val) {
    return this.setChannel("hwb", 2, val);
  },

  value: function(val) {
    return this.setChannel("hsv", 2, val);
  },

  cyan: function(val) {
    return this.setChannel("cmyk", 0, val);
  },

  magenta: function(val) {
    return this.setChannel("cmyk", 1, val);
  },

  yellow: function(val) {
    return this.setChannel("cmyk", 2, val);
  },

  black: function(val) {
    return this.setChannel("cmyk", 3, val);
  },

  luminosity: function() {
    // http://www.w3.org/TR/WCAG20/#relativeluminancedef
    var rgb = this.values.rgb;
    var lum = [];
    for (var i = 0; i < rgb.length; i++) {
      var chan = rgb[i] / 255;
      lum[i] = (chan <= 0.03928) ? chan / 12.92
                : Math.pow(((chan + 0.055) / 1.055), 2.4)
    }
    return 0.2126 * lum[0] + 0.7152 * lum[1] + 0.0722 * lum[2];
  },

  contrast: function(color2) {
    // http://www.w3.org/TR/WCAG20/#contrast-ratiodef
    var lum1 = this.luminosity();
    var lum2 = color2.luminosity();
    if (lum1 > lum2) {
       return (lum1 + 0.05) / (lum2 + 0.05)
    };
    return (lum2 + 0.05) / (lum1 + 0.05);
  },

  level: function(color2) {
    var contrastRatio = this.contrast(color2);
    return (contrastRatio >= 7.1)
      ? 'AAA'
      : (contrastRatio >= 4.5)
       ? 'AA'
       : '';
  },

  dark: function() {
    // YIQ equation from http://24ways.org/2010/calculating-color-contrast
    var rgb = this.values.rgb,
        yiq = (rgb[0] * 299 + rgb[1] * 587 + rgb[2] * 114) / 1000;
    return yiq < 128;
  },

  light: function() {
    return !this.dark();
  },

  negate: function() {
    var rgb = []
    for (var i = 0; i < 3; i++) {
       rgb[i] = 255 - this.values.rgb[i];
    }
    this.setValues("rgb", rgb);
    return this;
  },

  lighten: function(ratio) {
    this.values.hsl[2] += this.values.hsl[2] * ratio;
    this.setValues("hsl", this.values.hsl);
    return this;
  },

  darken: function(ratio) {
    this.values.hsl[2] -= this.values.hsl[2] * ratio;
    this.setValues("hsl", this.values.hsl);
    return this;
  },

  saturate: function(ratio) {
    this.values.hsl[1] += this.values.hsl[1] * ratio;
    this.setValues("hsl", this.values.hsl);
    return this;
  },

  desaturate: function(ratio) {
    this.values.hsl[1] -= this.values.hsl[1] * ratio;
    this.setValues("hsl", this.values.hsl);
    return this;
  },

  whiten: function(ratio) {
    this.values.hwb[1] += this.values.hwb[1] * ratio;
    this.setValues("hwb", this.values.hwb);
    return this;
  },

  blacken: function(ratio) {
    this.values.hwb[2] += this.values.hwb[2] * ratio;
    this.setValues("hwb", this.values.hwb);
    return this;
  },

  greyscale: function() {
    var rgb = this.values.rgb;
    // http://en.wikipedia.org/wiki/Grayscale#Converting_color_to_grayscale
    var val = rgb[0] * 0.3 + rgb[1] * 0.59 + rgb[2] * 0.11;
    this.setValues("rgb", [val, val, val]);
    return this;
  },

  clearer: function(ratio) {
    this.setValues("alpha", this.values.alpha - (this.values.alpha * ratio));
    return this;
  },

  opaquer: function(ratio) {
    this.setValues("alpha", this.values.alpha + (this.values.alpha * ratio));
    return this;
  },

  rotate: function(degrees) {
    var hue = this.values.hsl[0];
    hue = (hue + degrees) % 360;
    hue = hue < 0 ? 360 + hue : hue;
    this.values.hsl[0] = hue;
    this.setValues("hsl", this.values.hsl);
    return this;
  },

  /**
   * Ported from sass implementation in C
   * https://github.com/sass/libsass/blob/0e6b4a2850092356aa3ece07c6b249f0221caced/functions.cpp#L209
   */
  mix: function(mixinColor, weight) {
    var color1 = this;
    var color2 = mixinColor;
    var p = weight !== undefined ? weight : 0.5;

    var w = 2 * p - 1;
    var a = color1.alpha() - color2.alpha();

    var w1 = (((w * a == -1) ? w : (w + a)/(1 + w*a)) + 1) / 2.0;
    var w2 = 1 - w1;

    return this
      .rgb(
        w1 * color1.red() + w2 * color2.red(),
        w1 * color1.green() + w2 * color2.green(),
        w1 * color1.blue() + w2 * color2.blue()
      )
      .alpha(color1.alpha() * p + color2.alpha() * (1 - p));
  },

  toJSON: function() {
    return this.rgb();
  },

  copy: function() {
    return new Color().rgb(this.rgb());
  },

  getValues: function(space) {
    var vals = {};
    for (var i = 0; i < space.length; i++) {
      vals[space.charAt(i)] = this.values[space][i];
    }
    if (this.values.alpha != 1) {
      vals["a"] = this.values.alpha;
    }
    // {r: 255, g: 255, b: 255, a: 0.4}
    return vals;
  },

  setValues: function(space, vals) {

    var spaces = {
      "rgb": ["red", "green", "blue"],
      "hsl": ["hue", "saturation", "lightness"],
      "hsv": ["hue", "saturation", "value"],
      "hwb": ["hue", "whiteness", "blackness"],
      "cmyk": ["cyan", "magenta", "yellow", "black"]
    };

    var maxes = {
      "rgb": [255, 255, 255],
      "hsl": [360, 100, 100],
      "hsv": [360, 100, 100],
      "hwb": [360, 100, 100],
      "cmyk": [100, 100, 100, 100]
    };

    var alpha = 1;
    if (space == "alpha") {
       alpha = vals;
    }
    else if (vals.length) {
      // [10, 10, 10]
      this.values[space] = vals.slice(0, space.length);
      alpha = vals[space.length];
    }
    else if (vals[space.charAt(0)] !== undefined) {
      // {r: 10, g: 10, b: 10}
      for (var i = 0; i < space.length; i++) {
        this.values[space][i] = vals[space.charAt(i)];
      }
      alpha = vals.a;
    }
    else if (vals[spaces[space][0]] !== undefined) {
      // {red: 10, green: 10, blue: 10}
      var chans = spaces[space];
      for (var i = 0; i < space.length; i++) {
        this.values[space][i] = vals[chans[i]];
      }
      alpha = vals.alpha;
    }
    this.values.alpha = Math.max(0, Math.min(1, (alpha !== undefined ? alpha : this.values.alpha) ));
    if (space == "alpha") {
      return;
    }

    // cap values of the space prior converting all values
    for (var i = 0; i < space.length; i++) {
      var capped = Math.max(0, Math.min(maxes[space][i], this.values[space][i]));
      this.values[space][i] = Math.round(capped);
    }

    // convert to all the other color spaces
    for (var sname in spaces) {
      if (sname != space) {
        this.values[sname] = colorConvert[space][sname](this.values[space])
      }

      // cap values
      for (var i = 0; i < sname.length; i++) {
        var capped = Math.max(0, Math.min(maxes[sname][i], this.values[sname][i]));
        this.values[sname][i] = Math.round(capped);
      }
    }
    return true;
  },

  setSpace: function(space, args) {
    var vals = args[0];
    if (vals === undefined) {
      // color.rgb()
      return this.getValues(space);
    }
    // color.rgb(10, 10, 10)
    if (typeof vals == "number") {
      vals = Array.prototype.slice.call(args);
    }
    this.setValues(space, vals);
    return this;
  },

  setChannel: function(space, index, val) {
    if (val === undefined) {
      // color.red()
      return this.values[space][index];
    }
    // color.red(100)
    this.values[space][index] = val;
    this.setValues(space, this.values[space]);
    return this;
  }

}

// Modules should be accessible through Color
Color.Convert = colorConvert;

module.exports = Color;

==> rune.js-1.1.3.tgz: package/src/color.js <==
// This code was adapted from the brilliant color lib by MoOx
// See more here: https://github.com/MoOx/color
var colorConvert = require("color-convert");
var colorParse = require("parse-color");

var Color = function(a, b, c, d, e) {
  this.values = {
    rgb: [0, 0, 0],
    hsl: [0, 0, 0],
    hsv: [0, 0, 0],
    hwb: [0, 0, 0],
    cmyk: [0, 0, 0, 0],
    alpha: 1
  };

  // COLOR
  if (a instanceof Color) {
    return a;
  } else if (a == "hsv") {
    // HSB
    this.setValues("hsv", { h: b % 360, s: c, v: d });
    if (e) this.setValues("alpha", e);
  } else if (typeof a === "string") {
    // HEX
    // convert HEX to RGB
    var result = colorParse(a);
    if (result.rgb) {
      this.setValues("rgb", result.rgb);
      if (result.rgba) this.setValues("alpha", result.rgba[3]);
    } else {
      throw new Error('Unable to parse color from string "' + a + '"');
    }
    if (b) this.setValues("alpha", b);
  } else if (typeof c === "undefined") {
    // GRAYSCALE
    this.setValues("rgb", { r: a, g: a, b: a });
    if (b) this.setValues("alpha", b);
  } else if (typeof a !== "undefined") {
    // RGB
    this.setValues("rgb", { r: a, g: b, b: c });
    if (d) this.setValues("alpha", d);
  }
};

Color.prototype = {
  type: "color",

  rgb: function(vals) {
    return this.setSpace("rgb", arguments);
  },

  hsl: function(vals) {
    return this.setSpace("hsl", arguments);
  },

  hsv: function(vals) {
    return this.setSpace("hsv", arguments);
  },

  hwb: function(vals) {
    return this.setSpace("hwb", arguments);
  },

  cmyk: function(vals) {
    return this.setSpace("cmyk", arguments);
  },

  rgbArray: function() {
    return this.values.rgb;
  },

  hslArray: function() {
    return this.values.hsl;
  },

  hsvArray: function() {
    return this.values.hsv;
  },

  hwbArray: function() {
    if (this.values.alpha !== 1) {
      return this.values.hwb.concat([this.values.alpha]);
    }
    return this.values.hwb;
  },

  cmykArray: function() {
    return this.values.cmyk;
  },

  rgbaArray: function() {
    var rgb = this.values.rgb;
    return rgb.concat([this.values.alpha]);
  },

  hslaArray: function() {
    var hsl = this.values.hsl;
    return hsl.concat([this.values.alpha]);
  },

  alpha: function(val) {
    if (val === undefined) {
      return this.values.alpha;
    }
    this.setValues("alpha", val);
    return this;
  },

  red: function(val) {
    return this.setChannel("rgb", 0, val);
  },

  green: function(val) {
    return this.setChannel("rgb", 1, val);
  },

  blue: function(val) {
    return this.setChannel("rgb", 2, val);
  },

  hue: function(val) {
    return this.setChannel("hsl", 0, val);
  },

  saturation: function(val) {
    return this.setChannel("hsl", 1, val);
  },

  lightness: function(val) {
    return this.setChannel("hsl", 2, val);
  },

  saturationv: function(val) {
    return this.setChannel("hsv", 1, val);
  },

  whiteness: function(val) {
    return this.setChannel("hwb", 1, val);
  },

  blackness: function(val) {
    return this.setChannel("hwb", 2, val);
  },

  value: function(val) {
    return this.setChannel("hsv", 2, val);
  },

  cyan: function(val) {
    return this.setChannel("cmyk", 0, val);
  },

  magenta: function(val) {
    return this.setChannel("cmyk", 1, val);
  },

  yellow: function(val) {
    return this.setChannel("cmyk", 2, val);
  },

  black: function(val) {
    return this.setChannel("cmyk", 3, val);
  },

  luminosity: function() {
    // http://www.w3.org/TR/WCAG20/#relativeluminancedef
    var rgb = this.values.rgb;
    var lum = [];
    for (var i = 0; i < rgb.length; i++) {
      var chan = rgb[i] / 255;
      lum[i] =
        chan <= 0.03928 ? chan / 12.92 : Math.pow((chan + 0.055) / 1.055, 2.4);
    }
    return 0.2126 * lum[0] + 0.7152 * lum[1] + 0.0722 * lum[2];
  },

  contrast: function(color2) {
    // http://www.w3.org/TR/WCAG20/#contrast-ratiodef
    var lum1 = this.luminosity();
    var lum2 = color2.luminosity();
    if (lum1 > lum2) {
      return (lum1 + 0.05) / (lum2 + 0.05);
    }
    return (lum2 + 0.05) / (lum1 + 0.05);
  },

  level: function(color2) {
    var contrastRatio = this.contrast(color2);
    return contrastRatio >= 7.1 ? "AAA" : contrastRatio >= 4.5 ? "AA" : "";
  },

  dark: function() {
    // YIQ equation from http://24ways.org/2010/calculating-color-contrast
    var rgb = this.values.rgb,
      yiq = (rgb[0] * 299 + rgb[1] * 587 + rgb[2] * 114) / 1000;
    return yiq < 128;
  },

  light: function() {
    return !this.dark();
  },

  negate: function() {
    var rgb = [];
    for (var i = 0; i < 3; i++) {
      rgb[i] = 255 - this.values.rgb[i];
    }
    this.setValues("rgb", rgb);
    return this;
  },

  lighten: function(ratio) {
    this.values.hsl[2] += this.values.hsl[2] * ratio;
    this.setValues("hsl", this.values.hsl);
    return this;
  },

  darken: function(ratio) {
    this.values.hsl[2] -= this.values.hsl[2] * ratio;
    this.setValues("hsl", this.values.hsl);
    return this;
  },

  saturate: function(ratio) {
    this.values.hsl[1] += this.values.hsl[1] * ratio;
    this.setValues("hsl", this.values.hsl);
    return this;
  },

  desaturate: function(ratio) {
    this.values.hsl[1] -= this.values.hsl[1] * ratio;
    this.setValues("hsl", this.values.hsl);
    return this;
  },

  whiten: function(ratio) {
    this.values.hwb[1] += this.values.hwb[1] * ratio;
    this.setValues("hwb", this.values.hwb);
    return this;
  },

  blacken: function(ratio) {
    this.values.hwb[2] += this.values.hwb[2] * ratio;
    this.setValues("hwb", this.values.hwb);
    return this;
  },

  greyscale: function() {
    var rgb = this.values.rgb;
    // http://en.wikipedia.org/wiki/Grayscale#Converting_color_to_grayscale
    var val = rgb[0] * 0.3 + rgb[1] * 0.59 + rgb[2] * 0.11;
    this.setValues("rgb", [val, val, val]);
    return this;
  },

  clearer: function(ratio) {
    this.setValues("alpha", this.values.alpha - this.values.alpha * ratio);
    return this;
  },

  opaquer: function(ratio) {
    this.setValues("alpha", this.values.alpha + this.values.alpha * ratio);
    return this;
  },

  rotate: function(degrees) {
    var hue = this.values.hsl[0];
    hue = (hue + degrees) % 360;
    hue = hue < 0 ? 360 + hue : hue;
    this.values.hsl[0] = hue;
    this.setValues("hsl", this.values.hsl);
    return this;
  },

  /**
   * Ported from sass implementation in C
   * https://github.com/sass/libsass/blob/0e6b4a2850092356aa3ece07c6b249f0221caced/functions.cpp#L209
   */
  mix: function(mixinColor, weight) {
    var color1 = this;
    var color2 = mixinColor;
    var p = weight !== undefined ? weight : 0.5;

    var w = 2 * p - 1;
    var a = color1.alpha() - color2.alpha();

    var w1 = ((w * a == -1 ? w : (w + a) / (1 + w * a)) + 1) / 2.0;
    var w2 = 1 - w1;

    return this.rgb(
      w1 * color1.red() + w2 * color2.red(),
      w1 * color1.green() + w2 * color2.green(),
      w1 * color1.blue() + w2 * color2.blue()
    ).alpha(color1.alpha() * p + color2.alpha() * (1 - p));
  },

  toJSON: function() {
    return this.rgb();
  },

  copy: function() {
    return new Color().rgb(this.rgb());
  },

  getValues: function(space) {
    var vals = {};
    for (var i = 0; i < space.length; i++) {
      vals[space.charAt(i)] = this.values[space][i];
    }
    if (this.values.alpha != 1) {
      vals["a"] = this.values.alpha;
    }
    // {r: 255, g: 255, b: 255, a: 0.4}
    return vals;
  },

  setValues: function(space, vals) {
    var spaces = {
      rgb: ["red", "green", "blue"],
      hsl: ["hue", "saturation", "lightness"],
      hsv: ["hue", "saturation", "value"],
      hwb: ["hue", "whiteness", "blackness"],
      cmyk: ["cyan", "magenta", "yellow", "black"]
    };

    var maxes = {
      rgb: [255, 255, 255],
      hsl: [360, 100, 100],
      hsv: [360, 100, 100],
      hwb: [360, 100, 100],
      cmyk: [100, 100, 100, 100]
    };

    var alpha = 1;
    if (space == "alpha") {
      alpha = vals;
    } else if (vals.length) {
      // [10, 10, 10]
      this.values[space] = vals.slice(0, space.length);
      alpha = vals[space.length];
    } else if (vals[space.charAt(0)] !== undefined) {
      // {r: 10, g: 10, b: 10}
      for (var i = 0; i < space.length; i++) {
        this.values[space][i] = vals[space.charAt(i)];
      }
      alpha = vals.a;
    } else if (vals[spaces[space][0]] !== undefined) {
      // {red: 10, green: 10, blue: 10}
      var chans = spaces[space];
      for (var i = 0; i < space.length; i++) {
        this.values[space][i] = vals[chans[i]];
      }
      alpha = vals.alpha;
    }
    this.values.alpha = Math.max(
      0,
      Math.min(1, alpha !== undefined ? alpha : this.values.alpha)
    );
    if (space == "alpha") {
      return;
    }

    // cap values of the space prior converting all values
    for (var i = 0; i < space.length; i++) {
      var capped = Math.max(
        0,
        Math.min(maxes[space][i], this.values[space][i])
      );
      this.values[space][i] = Math.round(capped);
    }

    // convert to all the other color spaces
    for (var sname in spaces) {
      if (sname != space) {
        this.values[sname] = colorConvert[space][sname](this.values[space]);
      }

      // cap values
      for (var i = 0; i < sname.length; i++) {
        var capped = Math.max(
          0,
          Math.min(maxes[sname][i], this.values[sname][i])
        );
        this.values[sname][i] = Math.round(capped);
      }
    }
    return true;
  },

  setSpace: function(space, args) {
    var vals = args[0];
    if (vals === undefined) {
      // color.rgb()
      return this.getValues(space);
    }
    // color.rgb(10, 10, 10)
    if (typeof vals == "number") {
      vals = Array.prototype.slice.call(args);
    }
    this.setValues(space, vals);
    return this;
  },

  setChannel: function(space, index, val) {
    if (val === undefined) {
      // color.red()
      return this.values[space][index];
    }
    // color.red(100)
    this.values[space][index] = val;
    this.setValues(space, this.values[space]);
    return this;
  }
};

// Modules should be accessible through Color
Color.Convert = colorConvert;

module.exports = Color;
